@@ -21,6 +21,7 @@
 #include "TransactionModel.h"
 
 // Qt includes
+#include <QtCore/QDebug>
 #include <QtCore/QMetaProperty>
 #include <KLocalizedString>
 
@@ -181,15 +182,22 @@ void TransactionModel::cancelTransaction(Transaction *trans)
 void TransactionModel::removeTransaction(Transaction *trans)
 {
     Q_ASSERT(trans);
-    int r = indexOf(trans).row();
-    Q_ASSERT(r>=0);
+    int r = m_transactions.indexOf(trans);
+    if (r<0) {
+        qWarning() << "transaction not part of the model already" << trans;
+        return;
+    }
+
+    disconnect(trans, nullptr, this, nullptr);
 
     beginRemoveRows(QModelIndex(), r, r);
     m_transactions.removeAt(r);
     endRemoveRows();
+
     emit transactionRemoved(trans);
     if (m_transactions.isEmpty())
-        emit lastTransactionFinished(); 
+        emit lastTransactionFinished();
+    trans->deleteLater();
 }
 
 void TransactionModel::transactionChanged(int role)
