@@ -124,7 +124,7 @@ KNSBackend::KNSBackend(QObject* parent, const QString& iconName, const QString &
     connect(m_engine, &KNSCore::Engine::signalEntriesLoaded, this, &KNSBackend::receivedEntries, Qt::QueuedConnection);
     connect(m_engine, &KNSCore::Engine::signalEntryChanged, this, &KNSBackend::statusChanged);
     connect(m_engine, &KNSCore::Engine::signalEntryDetailsLoaded, this, &KNSBackend::statusChanged);
-    connect(m_engine, &KNSCore::Engine::signalProvidersLoaded, m_engine, &KNSCore::Engine::checkForInstalled);
+    connect(m_engine, &KNSCore::Engine::signalProvidersLoaded, this, &KNSBackend::fetchInstalled);
     connect(m_engine, &KNSCore::Engine::signalResetView, this, [this](){
         // If KNS tells us we should reset the view, what that means here is to remove
         // references to all the resources we've already told the agregator model about
@@ -135,7 +135,6 @@ KNSBackend::KNSBackend(QObject* parent, const QString& iconName, const QString &
         }
         m_resourcesByName.clear();
     });
-    m_responsePending = true;
 
     const QVector<QPair<FilterType, QString>> filters = { {CategoryFilter, fileName } };
     const QSet<QString> backendName = { name() };
@@ -169,6 +168,22 @@ void KNSBackend::markInvalid(const QString &message)
     setFetching(false);
 }
 
+void KNSBackend::fetchInstalled()
+{
+    auto search = new OneTimeAction([this]() {
+        Q_EMIT startingSearch();
+        m_onePage = true;
+        m_responsePending = true;
+        m_engine->checkForInstalled();
+    }, this);
+
+    if (m_responsePending) {
+        connect(this, &KNSBackend::availableForQueries, search, &OneTimeAction::trigger, Qt::QueuedConnection);
+    } else {
+        search->trigger();
+    }
+}
+
 void KNSBackend::setFetching(bool f)
 {
     if(m_fetching!=f) {
@@ -210,7 +225,7 @@ void KNSBackend::receivedEntries(const KNSCore::EntryInternal::List& entries)
         return;
     }
 //     qDebug() << "received" << objectName() << this << m_resourcesByName.count();
-    if (!m_responsePending) {
+    if (!m_responsePending && !m_onePage) {
         // We _have_ to set this first. If we do not, we may run into a situation where the
         // data request will conclude immediately, causing m_responsePending to remain true
         // for perpetuity as the slots will be called before the function returns.
@@ -322,25 +337,28 @@ ResultsStream* KNSBackend::search(const AbstractResourcesBackend::Filters& filte
         return new ResultsStream(QStringLiteral("KNS-installed"), ret);
     } else if (filter.category && filter.category->matchesCategoryName(m_categories.constFirst())) {
         return searchStream(filter.search);
-    } else if (!filter.search.isEmpty()) {
+    } else if (!filter.category && !filter.search.isEmpty()) {
         return searchStream(filter.search);
     }
     return voidStream();
 }
 
-ResultsStream * KNSBackend::searchStream(const QString &searchText)
+ResultsStream* KNSBackend::searchStream(const QString &searchText)
 {
     Q_EMIT startingSearch();
 
     auto stream = new ResultsStream(QStringLiteral("KNS-search-")+name());
-    connect(this, &KNSBackend::receivedResources, stream, &ResultsStream::resourcesFound);
-    connect(this, &KNSBackend::searchFinished, stream, &ResultsStream::finish);
-    connect(this, &KNSBackend::startingSearch, stream, &ResultsStream::finish);
-    auto start = [this, searchText]() {
+    auto start = [this, stream, searchText]() {
         // No need to explicitly launch a search, setting the search term already does that for us
         m_engine->setSearchTerm(searchText);
+        m_onePage = false;
         m_responsePending = true;
+
+        connect(this, &KNSBackend::receivedResources, stream, &ResultsStream::resourcesFound);
+        connect(this, &KNSBackend::searchFinished, stream, &ResultsStream::finish);
+        connect(this, &KNSBackend::startingSearch, stream, &ResultsStream::finish);
     };
+
     if (m_responsePending) {
         connect(this, &KNSBackend::availableForQueries, stream, start, Qt::QueuedConnection);
     } else {
@@ -367,6 +385,7 @@ ResultsStream * KNSBackend::findResourceByPackageName(const QUrl& search)
     auto start = [this, entryid, stream, providerid]() {
         m_responsePending = true;
         m_engine->fetchEntryById(entryid);
+        m_onePage = false;
         connect(m_engine, &KNSCore::Engine::signalError, stream, &ResultsStream::finish);
         connect(m_engine, &KNSCore::Engine::signalEntryDetailsLoaded, stream, [this, stream, entryid, providerid](const KNSCore::EntryInternal &entry) {
             if (entry.uniqueId() == entryid && providerid == QUrl(entry.providerId()).host()) {
