@@ -38,7 +38,6 @@ class DISCOVERCOMMON_EXPORT ResourcesUpdatesModel : public QStandardItemModel
 {
     Q_OBJECT
     Q_PROPERTY(qreal progress READ progress NOTIFY progressChanged)
-    Q_PROPERTY(QString remainingTime READ remainingTime NOTIFY etaChanged)
     Q_PROPERTY(bool isCancelable READ isCancelable NOTIFY cancelableChanged)
     Q_PROPERTY(bool isProgressing READ isProgressing NOTIFY progressingChanged)
     Q_PROPERTY(QDateTime lastUpdate READ lastUpdate NOTIFY progressingChanged)
@@ -47,7 +46,6 @@ class DISCOVERCOMMON_EXPORT ResourcesUpdatesModel : public QStandardItemModel
         explicit ResourcesUpdatesModel(QObject* parent = nullptr);
         
         qreal progress() const;
-        QString remainingTime() const;
         quint64 downloadSpeed() const;
         Q_SCRIPTABLE void prepare();
 
@@ -65,7 +63,6 @@ class DISCOVERCOMMON_EXPORT ResourcesUpdatesModel : public QStandardItemModel
     Q_SIGNALS:
         void downloadSpeedChanged();
         void progressChanged();
-        void etaChanged();
         void cancelableChanged();
         void progressingChanged(bool progressing);
         void finished();
